<?php 

/**
 * construx functions and definitions
 * @package construx
 */

if( ! function_exists( 'construx_theme_setup' ) )
 {

	function construx_theme_setup() {
		
	    load_theme_textdomain( 'construx', get_template_directory() . '/lang' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );
		
		// Add default title support
		add_theme_support( 'title-tag' ); 		

		// Add default logo support		
        add_theme_support( 'custom-logo' );	

        // To use additional css
 	    add_editor_style( 'css/editor-style.css' );		

		// Custom Backgrounds
		
	    
		add_theme_support('post-thumbnails');
		


		
		$defaults = array(
			'default-image'          => get_template_directory_uri() .'/assets/img/banner.jpg',
			'width'                  => 1920,
			'height'                 => 540,
			'uploads'                => true,
			'default-text-color'     => "656565",
			'wp-head-callback'       => 'construx_header_style',

			);
		add_theme_support( 'custom-header', $defaults );

		/**
		* Set the content width in pixels, based on the theme's design and stylesheet.
		*/
function construx_content_width() {
$GLOBALS['content_width'] = apply_filters( 'construx_content_width', 980 );
}
add_action( 'after_setup_theme', 'construx_content_width', 0 );		

		// Add theme support for Semantic Markup
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption'
		) );
		 
		 add_theme_support( 'customize-selective-refresh-widgets' );
		 
		// add excerpt support for pages
		add_post_type_support( 'page', 'excerpt' );
		
		if ( is_singular() && comments_open() ) {
			wp_enqueue_script( 'comment-reply' );
		}
	   
		// Menus
		//add_theme_support( 'menus' );

        register_nav_menus(array(
       'primary' => esc_html__('primary Menu', 'construx')
       ));	

		//Welcome Message 		
			if ( is_admin() ) {
				require( get_template_directory() . '/welcome-message.php');
			}

	}
	add_action( 'after_setup_theme', 'construx_theme_setup' );
    }

require get_template_directory(). '/inc/header-custom.php';
require get_template_directory(). '/inc/customizer.php';
require get_template_directory() . '/wp-bootstrap-navwalker.php';

 require get_template_directory(). '/pro-feat.php';


if ( version_compare( $GLOBALS['wp_version'], '4.7', '<' ) ) {
	require get_template_directory() . '/inc/notice.php';
	return;
}

/**
 * Enqueue CSS stylesheets
 */
  
if( ! function_exists( 'construx_enqueue_styles' ) ) {
	function construx_enqueue_styles() {
		
	// Bootstrap CSS 
	wp_enqueue_style('construx-main_font', 'https://fonts.googleapis.com/css?family=Raleway:100,100i,200,200i,300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i');
    wp_enqueue_style('bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', array(), '', 'all');
	
	wp_enqueue_style('font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', array(), '', 'all');

	wp_enqueue_style('slicknav', get_template_directory_uri() . '/assets/css/slicknav.css', array(), '', 'all');
	wp_enqueue_style('jquery-owl-carousel', get_template_directory_uri() . '/assets/css/owl.carousel.css', array(), '', 'all');

	wp_enqueue_style('construx-responsive', get_template_directory_uri() . '/assets/css/responsive.css', array(), '', 'all');

	wp_enqueue_style( 'construx-style', get_stylesheet_uri() );
	
	}
	add_action( 'wp_enqueue_scripts', 'construx_enqueue_styles' );
}

/**
 * Enqueue JS scripts
 */

if( ! function_exists( 'construx_enqueue_scripts' ) ) {
	function construx_enqueue_scripts() {
   
	    wp_enqueue_script('bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array('jquery'), '', true);
		wp_enqueue_script('jquery-slicknav', get_template_directory_uri() . '/assets/js/jquery.slicknav.js', array(), '', true);	
		wp_enqueue_script('jquery-sticky', get_template_directory_uri() . '/assets/js/jquery.sticky.js', array(), '', true);
		wp_enqueue_script('construx-main', get_template_directory_uri() . '/assets/js/main.js', array(), '', true);
		wp_enqueue_script('jquery-owl-carousel', get_template_directory_uri() . '/assets/js/owl.carousel.js', array(), '', true);
		wp_enqueue_script('construx-skip-links', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '', true);

	}		

	add_action( 'wp_enqueue_scripts', 'construx_enqueue_scripts' );
}

function construx_sidebars() {

	register_sidebar(array(
		'name' => esc_html__( 'Blog Sidebar', "construx"),
		'id' => 'blog-sidebar',
		'description' => esc_html__( 'Sidebar on the blog layout.', "construx"),
		'before_widget' => '<div id="%1$s" class="%2$s clearfix">',
		'after_widget' => '</div>',
		'before_title' => '<h4 class="widget-title">',
		'after_title' => '</h4>',
	));
		
	register_sidebar(array(
		'name' => esc_html__( 'Footer Widget Area', "construx"),
		'id' => 'construx-footer-widget-area',
		'description' => esc_html__( 'The footer widget area', "construx"),
		'before_widget' => '<div class="%2$s footer-widget col-md-4 col-sm-6 col-xs-12">',
		'after_widget' => '</div>',
		'before_title' => ' <h3>',
		'after_title' => '</h3>',
	));	
		
}
add_action( 'widgets_init', 'construx_sidebars' );

/**
 * Load Upsell Button In Customizer
 * 2016 &copy; [Justin Tadlock](http://justintadlock.com).
 */

require_once( trailingslashit( get_template_directory() ) . '/lib/upgrade/class-customize.php' );

/**
 * admin  JS scripts
 */
function construx_admin_enqueue_scripts( $hook ) { 
	wp_enqueue_style( 
		'font-awesome', 
		get_template_directory_uri() . '/assets/css/font-awesome.css', 
		array(), 
		'4.7.0', 
		'all' 
	);
	wp_enqueue_style( 
		'construx-admin', 
		get_template_directory_uri() . '/assets/admin/css/admin.css', 
		array(), 
		'1.0.0', 
		'all' 
	);
 
}
add_action( 'admin_enqueue_scripts', 'construx_admin_enqueue_scripts' );

function construx_placeholders( $fields )
{
    $fields['author'] = str_replace(
        '<input',
        '<input placeholder="'
            . _x(
                'Your Name',
                'comment form placeholder',
                'construx'
                )
            . '"',
        $fields['author']
    );
    $fields['email'] = str_replace(
        '<input',
        '<input placeholder="'
            . _x(
                'Your Email',
                'comment form placeholder',
                'construx'
                )
            . '"',
        $fields['email']
    );

    return $fields;
}

add_filter( 'comment_form_default_fields', 'construx_placeholders' );

 
function construx_comment_reform ($arg) {
$arg['title_reply'] = esc_html__('Add Comment','construx');
return $arg;
}
add_filter('comment_form_defaults','construx_comment_reform');


function construx_textarea_placeholder( $fields )
{
    $fields['comment_field'] = str_replace(
    '<textarea',
    '<textarea placeholder="'
    . esc_attr__('Comment','construx').'"',
    $fields['comment_field']
    );
   
 
    return $fields;
}

add_filter( 'comment_form_defaults', 'construx_textarea_placeholder' );


if ( ! function_exists( 'construx_customize_search_form' ) ) :

	function construx_customize_search_form() {

		$form = '<form role="search" method="get" class="side-form" action="' . esc_url( home_url( '/' ) ) . '">
					<input type="search"  placeholder="' . esc_attr_x( ' search here', 'placeholder', 'construx' ) . '" value="' . get_search_query() . '" name="s" title="' . esc_attr_x( 'Search for:', 'label', 'construx' ) . '" />
					
					<button type="submit">
						<i class="fa fa-search"></i>
					</button>  
		        </form>';
		return $form;
	}
	
endif;

add_filter( 'get_search_form', 'construx_customize_search_form', 15 );

function construx_comments( $comment, $args, $depth ) { ?>
	<div id="comment-<?php comment_ID(); ?>" <?php comment_class('comment-section'); ?>>
		<?php if ($comment->comment_approved == '0') : ?>
			<div class="alert alert-info">
			  <p><?php esc_html_e( 'Your comment is awaiting moderation.', 'construx' ) ?></p>
			</div>
		<?php endif; ?>

		<div class="single-comment-item">
			<div class="row">
				<div class="col-md-1">
					<div class="comment-avater-img">
					<?php echo get_avatar( $comment,60, null,'comments user', array( 'class' => array( 'media-object','' ) )); ?>
					</div>
			   </div>
				<div class="col-md-11">	
					<div class="single-comment-text"> 
						<h4>
							<?php 
								/* translators: '%1$s %2$s: edit term */
							   printf(esc_html__( '%1$s %2$s-', 'construx' ), get_comment_author_link(), edit_comment_link(esc_html__( '(Edit)', 'construx' ),'  ','') ) ?>
						   <span class="date"><?php echo esc_html(get_the_date());?></span>
						</h4>
						
						<p><?php comment_text() ?></p>
					   <?php comment_reply_link (array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
				   </div>
				</div>
			</div>
		</div>
	</div>
<?php } ?>