<?php
/**
 * Construx back compat functionality
 *
 * Prevents Construx from running on WordPress versions prior to 4.7,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.7.
 *
 * @package WordPress
 * @subpackage construx
 * @since Construx 1.3
 */

/**
 * Prevent switching to Construx on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since Construx 1.3
 */
function construx_switch_theme() {
	switch_theme( WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'construx_upgrade_notice' );
}
add_action( 'after_switch_theme', 'construx_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Construx on WordPress versions prior to 4.7.
 *
 * @since Construx 1.2
 *
 * @global string $wp_version WordPress version.
 */
function construx_upgrade_notice() {
	$message = sprintf( __( 'Construx requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'construx' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.7.
 *
 * @since Construx 1.2
 *
 * @global string $wp_version WordPress version.
 */
function construx_customize() {
	wp_die(
		sprintf(
			__( 'Construx requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'construx' ),
			$GLOBALS['wp_version']
		),
		'',
		array(
			'back_link' => true,
		)
	);
}
add_action( 'load-customize.php', 'construx_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.7.
 *
 * @since Construx 1.2
 *
 * @global string $wp_version WordPress version.
 */
function construx_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'Construx requires at least WordPress version 4.7. You are running version %s. Please upgrade and try again.', 'construx' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'construx_preview' );